==> tidkvideochange-0.1.0.tar.gz: tidkvideochange-0.1.0/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = ['Click>=6.0', 'tqdm', 'six', 'lmdb', 'numpy', 'matplotlib', 'torch', 'torchvision', 'pillow', 'importlib_resources', 'tensorflow-gpu']

setup_requirements = [ ]

test_requirements = [ ]

setup(
    author="Dominik Huss",
    author_email='dhuss@tidk.pl',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3.5',
    ],
    description="Custom modification of VideoText, incorporating pyscenedetect and batching frames.",
    entry_points={
        'console_scripts': [
            'tidkvideochange=tidkvideochange.cli:main',
        ],
    },
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='tidkvideochange',
    name='tidkvideochange',
    packages=['tidkvideochange',
              'tidkvideochange.crnnpytorch',
              'tidkvideochange.weights'],
    package_data={'tidkvideochange': ['weights/*.pth', 'weights/*.pb']},
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/DominikHuss/tidkvideochange',
    version='0.1.0',
    zip_safe=False,
)

==> tidkvideochange-0.1.1.tar.gz: tidkvideochange-0.1.1/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""
import sys

from setuptools import setup, find_packages

if sys.version_info <= (3, 4):
    print('TIDKVideoChange requires at least Python 3.5 to run.')
    sys.exit(1)

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = ['Click>=6.0', 'tqdm', 'six', 'lmdb', 'numpy', 'matplotlib', 'torch', 'torchvision', 'pillow', 'importlib_resources', 'opencv-python']
if sys.version_info >= (3, 7):
    requirements += ['tensorflow']
else:
    requirements += ['tensorflow-gpu']

setup_requirements = [ ]

test_requirements = [ ]

setup(
    author="Dominik Huss",
    author_email='dhuss@tidk.pl',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3.5',
    ],
    description="Custom modification of VideoText, incorporating pyscenedetect and batching frames.",
    entry_points={
        'console_scripts': [
            'tidkvideochange=tidkvideochange.cli:main',
        ],
    },
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='tidkvideochange',
    name='tidkvideochange',
    packages=['tidkvideochange',
              'tidkvideochange.crnnpytorch',
              'tidkvideochange.weights'],
    package_data={'tidkvideochange': ['weights/*.pth', 'weights/*.pb']},
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/DominikHuss/tidkvideochange',
    version='0.1.1',
    zip_safe=False,
)
